==> gimp_3.0.2.orig.tar.xz: gimp-3.0.2/.gitlab/issue_templates/Default.md <==
<!-- ⚠️ IMPORTANT: READ ME! ⚠️
This is the default template for bug reports.
For feature requests or performance issues, please switch instead to the appropriate template in the "Choose a template" list.

It is important that you fill all the fields of the template.

There are a few issues we get reports about quite frequently. If you want to check if what you have encountered is among these, please see: 
https://gitlab.gnome.org/GNOME/gimp/-/issues/?sort=updated_desc&state=all&label_name%5B%5D=Duplication%20target&first_page_size=100

**Code of Conduct**: "Be considerate and respectful" is our main rule.
E.g. avoid negative emotional writing which only generates more upsetting
interactions. Thanks!
-->

### Environment/Versions

- GIMP version:
- Package: <!--[flatpak? Installer from gimp.org? If another installer, tell us where from] (write it after the > symbol)-->
- Operating System: <!--[Windows? macOS? Linux? All? Add OS versions too] (write it after the > symbol) -->
- (if Linux) Display system: <!--[X11? Wayland? Which compositor and version?] (write it after the > symbol) -->

<!--Note: bug reporters are expected to have verified the bug still exists
either in the last stable version of GIMP or on updated development code
(master branch).-->

### Description of the bug

<!--Please describe your issue with details.
Add screenshot or other files if needed.(write it after the > symbol)-->

### Reproduction

Is the bug reproducible? <!--[Always / Randomly / Happened only once ] (write it after the > symbol)-->

Reproduction steps:

1. 
2. 
3. 

…

Expected result:

Actual result:

### Additional information

If you have a backtrace for a crash or a warning, paste it here.

==> gimp_3.0.4.orig.tar.xz: gimp-3.0.4/.gitlab/issue_templates/Default.md <==
<!-- ⚠️ IMPORTANT: READ ME! ⚠️
This is the default template for bug reports.
For feature requests or performance issues, please switch instead to the appropriate template in the "Choose a template" list.

It is important that you fill all the fields of the template.

There are a few issues we get reports about quite frequently. If you want to check if what you have encountered is among these, please see: 
https://gitlab.gnome.org/GNOME/gimp/-/issues/?sort=updated_desc&state=all&label_name%5B%5D=Duplication%20target&first_page_size=100

**Code of Conduct**: "Be considerate and respectful" is our main rule.
E.g. avoid negative emotional writing which only generates more upsetting
interactions. Thanks!
-->

### Environment/Versions

- GIMP version number:
- Package: <!--[flatpak? Installer from gimp.org? If another installer, tell us where from] (write it after the > symbol)-->
- Operating System: <!--[Windows? macOS? Linux? All? Add OS versions too] (write it after the > symbol) -->
- (if Linux) Display system: <!--[X11? Wayland? Which compositor and version?] (write it after the > symbol) -->

<!--Note: bug reporters are expected to have verified the bug still exists
either in the last stable version of GIMP or on updated development code
(master branch).-->

### Description of the bug

<!--Please describe your issue with details.
Add full (not cropped) screenshots or other files if needed.(write it after the > symbol)-->

### Reproduction

Is the bug reproducible? <!--[Always / Randomly / Happened only once ] (write it after the > symbol)-->

Reproduction steps:

1. 
2. 
3. 

…

Expected result:

Actual result:

### Additional information

If you have a backtrace for a crash or a warning, paste it here.
